==> flink-1.13.6-src.tgz: flink-1.13.6/flink-python/src/test/java/org/apache/flink/table/runtime/typeutils/serializers/python/BigDecSerializerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.runtime.typeutils.serializers.python;

import org.apache.flink.api.common.typeutils.SerializerTestBase;
import org.apache.flink.api.common.typeutils.TypeSerializer;

import java.math.BigDecimal;

/** Test for {@link BigDecSerializer}. */
public class BigDecSerializerTest extends SerializerTestBase<BigDecimal> {
    @Override
    protected TypeSerializer<BigDecimal> createSerializer() {
        return BigDecSerializer.INSTANCE;
    }

    @Override
    protected int getLength() {
        return -1;
    }

    @Override
    protected Class<BigDecimal> getTypeClass() {
        return BigDecimal.class;
    }

    @Override
    protected BigDecimal[] getTestData() {
        return new BigDecimal[] {
            BigDecimal.valueOf(1000L),
            BigDecimal.valueOf(200.0),
            new BigDecimal("111111111111111111111.1111111111")
        };
    }
}

==> flink-1.18.1-src.tgz: flink-1.18.1/flink-python/src/test/java/org/apache/flink/table/runtime/typeutils/serializers/python/BigDecSerializerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.runtime.typeutils.serializers.python;

import org.apache.flink.api.common.typeutils.SerializerTestBase;
import org.apache.flink.api.common.typeutils.TypeSerializer;

import java.math.BigDecimal;

/** Test for {@link BigDecSerializer}. */
class BigDecSerializerTest extends SerializerTestBase<BigDecimal> {
    @Override
    protected TypeSerializer<BigDecimal> createSerializer() {
        return BigDecSerializer.INSTANCE;
    }

    @Override
    protected int getLength() {
        return -1;
    }

    @Override
    protected Class<BigDecimal> getTypeClass() {
        return BigDecimal.class;
    }

    @Override
    protected BigDecimal[] getTestData() {
        return new BigDecimal[] {
            BigDecimal.valueOf(1000L),
            BigDecimal.valueOf(200.0),
            new BigDecimal("111111111111111111111.1111111111")
        };
    }
}
